@@ -1,5 +1,6 @@
 /* vi:set et sw=2 sts=2 cin cino=t0,f0,(0,{s,>2s,n-s,^-s,e-s:
  * Copyright © 2018 Red Hat, Inc
+ * Copyright © 2024 GNOME Foundation, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -16,6 +17,7 @@
  *
  * Authors:
  *       Alexander Larsson <alexl@redhat.com>
+ *       Hubert Figuière <hub@figuiere.net>
  */
 
 #include "config.h"
@@ -25,6 +27,7 @@
 #include "flatpak-installation-private.h"
 #include "flatpak-run-private.h"
 #include "flatpak-table-printer.h"
+#include "flatpak-tty-utils-private.h"
 #include "flatpak-utils-private.h"
 #include "flatpak-error.h"
 #include <glib/gi18n.h>
@@ -158,8 +161,8 @@ install_authenticator (FlatpakTransaction            *old_transaction,
   FlatpakCliTransaction *old_cli = FLATPAK_CLI_TRANSACTION (old_transaction);
   g_autoptr(FlatpakTransaction)  transaction2 = NULL;
   g_autoptr(GError) local_error = NULL;
-  FlatpakInstallation *installation = flatpak_transaction_get_installation (old_transaction);
-  FlatpakDir *dir = flatpak_installation_get_dir (installation, NULL);
+  g_autoptr(FlatpakInstallation) installation = flatpak_transaction_get_installation (old_transaction);
+  g_autoptr(FlatpakDir) dir = flatpak_installation_get_dir (installation, NULL);
 
   if (dir == NULL)
     {
@@ -375,6 +378,7 @@ progress_changed_cb (FlatpakTransactionProgress *progress,
         }
       if (!redraw (cli))
         g_print ("\r%s", str->str); /* redraw failed, just update the progress */
+      flatpak_pty_set_progress (percent);
     }
   else
     g_print ("%s\n", str->str);
@@ -844,8 +848,8 @@ find_reverse_dep_apps (FlatpakTransaction *transaction,
                                                                ref, NULL, &local_error);
       if (apps == NULL)
         {
-          g_debug ("Unable to list apps using extension %s: %s\n",
-                   flatpak_decomposed_get_ref (ref), local_error->message);
+          g_info ("Unable to list apps using extension %s: %s\n",
+                  flatpak_decomposed_get_ref (ref), local_error->message);
           return NULL;
         }
     }
@@ -856,8 +860,8 @@ find_reverse_dep_apps (FlatpakTransaction *transaction,
                                                      NULL, &local_error);
       if (apps == NULL)
         {
-          g_debug ("Unable to find apps using runtime %s: %s\n",
-                   flatpak_decomposed_get_ref (ref), local_error->message);
+          g_info ("Unable to find apps using runtime %s: %s\n",
+                  flatpak_decomposed_get_ref (ref), local_error->message);
           return NULL;
         }
     }
@@ -887,8 +891,8 @@ end_of_lifed_with_rebase (FlatpakTransaction *transaction,
   EolAction action = EOL_UNDECIDED;
   EolAction old_action = EOL_UNDECIDED;
   gboolean can_rebase = rebased_to_ref != NULL && remote != NULL;
-  FlatpakInstallation *installation = flatpak_transaction_get_installation (transaction);
-  FlatpakDir *dir = flatpak_installation_get_dir (installation, NULL);
+  g_autoptr(FlatpakInstallation) installation = flatpak_transaction_get_installation (transaction);
+  g_autoptr(FlatpakDir) dir = flatpak_installation_get_dir (installation, NULL);
 
   if (ref == NULL)
     return FALSE; /* Shouldn't happen, the ref should be valid */
@@ -978,7 +982,7 @@ end_of_lifed_with_rebase (FlatpakTransaction *transaction,
     }
   else
     {
-      g_debug ("%s is end-of-life, using action from parent ref", name);
+      g_info ("%s is end-of-life, using action from parent ref", name);
     }
 
   /* Cache for later comparison and reuse */
@@ -988,7 +992,7 @@ end_of_lifed_with_rebase (FlatpakTransaction *transaction,
     {
       g_autoptr(GError) error = NULL;
 
-      if (!flatpak_transaction_add_rebase (transaction, remote, rebased_to_ref, NULL, previous_ids, &error))
+      if (!flatpak_transaction_add_rebase_and_uninstall (transaction, remote, rebased_to_ref, ref_str, NULL, previous_ids, &error))
         {
           g_propagate_prefixed_error (&self->first_operation_error,
                                       g_error_copy (error),
@@ -997,21 +1001,6 @@ end_of_lifed_with_rebase (FlatpakTransaction *transaction,
           return FALSE;
         }
 
-      if (!flatpak_transaction_add_uninstall (transaction, ref_str, &error))
-        {
-          /* NOT_INSTALLED error is expected in case the op that triggered this was install not update */
-          if (g_error_matches (error, FLATPAK_ERROR, FLATPAK_ERROR_NOT_INSTALLED))
-            g_clear_error (&error);
-          else
-            {
-              g_propagate_prefixed_error (&self->first_operation_error,
-                                          g_error_copy (error),
-                                          _("Failed to uninstall %s for rebase to %s: "),
-                                          name, rebased_to_ref);
-              return FALSE;
-            }
-        }
-
       return TRUE; /* skip install/update op of end-of-life ref */
     }
   else /* IGNORE or NO_REBASE */
@@ -1096,6 +1085,56 @@ append_bus (GPtrArray  *talk,
     }
 }
 
+static void
+append_usb (GPtrArray *usb_array,
+            GKeyFile  *metadata,
+            GKeyFile  *old_metadata)
+{
+  gsize size = 0;
+  g_auto(GStrv) hidden_devices = NULL;
+  g_auto(GStrv) old_hidden_devices = NULL;
+  g_auto(GStrv) old_enumerables = NULL;
+  g_auto(GStrv) enumerables = NULL;
+
+  enumerables = g_key_file_get_string_list (metadata,
+                                            FLATPAK_METADATA_GROUP_USB_DEVICES,
+                                            FLATPAK_METADATA_KEY_USB_ENUMERABLE_DEVICES,
+                                            &size, NULL);
+
+  if (old_metadata)
+    old_enumerables = g_key_file_get_string_list (old_metadata,
+                                                  FLATPAK_METADATA_GROUP_USB_DEVICES,
+                                                  FLATPAK_METADATA_KEY_USB_ENUMERABLE_DEVICES,
+                                                  NULL, NULL);
+
+  for (size_t i = 0; i < size; i++)
+    {
+      const char *enumerable = enumerables[i];
+      if (old_enumerables == NULL || !g_strv_contains ((const char * const *) old_enumerables, enumerable))
+        g_ptr_array_add (usb_array, g_strdup (enumerable));
+    }
+
+  size = 0;
+
+  hidden_devices = g_key_file_get_string_list (metadata,
+                                               FLATPAK_METADATA_GROUP_USB_DEVICES,
+                                               FLATPAK_METADATA_KEY_USB_HIDDEN_DEVICES,
+                                               &size, NULL);
+
+  if (old_metadata)
+    old_hidden_devices = g_key_file_get_string_list (old_metadata,
+                                                     FLATPAK_METADATA_GROUP_USB_DEVICES,
+                                                     FLATPAK_METADATA_KEY_USB_HIDDEN_DEVICES,
+                                                     NULL, NULL);
+
+  for (size_t i = 0; i < size; i++)
+    {
+      const char *hidden = hidden_devices[i];
+      if (old_hidden_devices == NULL || !g_strv_contains ((const char * const *) old_hidden_devices, hidden))
+        g_ptr_array_add (usb_array, g_strdup_printf ("!%s", hidden));
+    }
+}
+
 static void
 append_tags (GPtrArray *tags_array,
              GKeyFile  *metadata,
@@ -1160,6 +1199,7 @@ print_permissions (FlatpakCliTransaction *self,
   g_autoptr(FlatpakRef) rref = flatpak_ref_parse (ref, NULL);
   g_autoptr(GPtrArray) permissions = g_ptr_array_new_with_free_func (g_free);
   g_autoptr(GPtrArray) files = g_ptr_array_new_with_free_func (g_free);
+  g_autoptr(GPtrArray) usb = g_ptr_array_new_with_free_func (g_free);
   g_autoptr(GPtrArray) session_bus_talk = g_ptr_array_new_with_free_func (g_free);
   g_autoptr(GPtrArray) session_bus_own = g_ptr_array_new_with_free_func (g_free);
   g_autoptr(GPtrArray) system_bus_talk = g_ptr_array_new_with_free_func (g_free);
@@ -1192,6 +1232,7 @@ print_permissions (FlatpakCliTransaction *self,
   append_permissions (permissions, metadata, old_metadata, FLATPAK_METADATA_KEY_DEVICES);
   append_permissions (permissions, metadata, old_metadata, FLATPAK_METADATA_KEY_FEATURES);
   append_permissions (files, metadata, old_metadata, FLATPAK_METADATA_KEY_FILESYSTEMS);
+  append_usb (usb, metadata, old_metadata);
   append_bus (session_bus_talk, session_bus_own,
               metadata, old_metadata, FLATPAK_METADATA_GROUP_SESSION_BUS_POLICY);
   append_bus (system_bus_talk, system_bus_own,
@@ -1209,6 +1250,8 @@ print_permissions (FlatpakCliTransaction *self,
     g_ptr_array_add (permissions, g_strdup_printf ("system dbus access [%d]", j++));
   if (system_bus_own->len > 0)
     g_ptr_array_add (permissions, g_strdup_printf ("system bus ownership [%d]", j++));
+  if (usb->len > 0)
+    g_ptr_array_add (permissions, g_strdup_printf ("USB portal access [%d]", j++));
   if (tags->len > 0)
     g_ptr_array_add (permissions, g_strdup_printf ("tags [%d]", j++));
 
@@ -1270,6 +1313,8 @@ print_permissions (FlatpakCliTransaction *self,
     print_perm_line (j++, system_bus_talk, cols);
   if (system_bus_own->len > 0)
     print_perm_line (j++, system_bus_own, cols);
+  if (usb->len > 0)
+    print_perm_line (j++, usb, cols);
   if (tags->len > 0)
     print_perm_line (j++, tags, cols);
 }
@@ -1301,7 +1346,7 @@ static gboolean
 transaction_ready_pre_auth (FlatpakTransaction *transaction)
 {
   FlatpakCliTransaction *self = FLATPAK_CLI_TRANSACTION (transaction);
-  GList *ops = flatpak_transaction_get_operations (transaction);
+  g_autolist(FlatpakTransactionOperation) ops = flatpak_transaction_get_operations (transaction);
   GList *l;
   int i;
   FlatpakTablePrinter *printer;
@@ -1481,10 +1526,7 @@ transaction_ready_pre_auth (FlatpakTransaction *transaction)
         ret = flatpak_yes_no_prompt (TRUE, _("Proceed with these changes to the %s?"), name);
 
       if (!ret)
-        {
-          g_list_free_full (ops, g_object_unref);
-          return FALSE;
-        }
+        return FALSE;
     }
   else
     g_print ("\n\n");
@@ -1643,6 +1685,7 @@ flatpak_cli_transaction_run (FlatpakTransaction *transaction,
 
   if (flatpak_fancy_output ())
     {
+      flatpak_pty_clear_progress ();
       flatpak_disable_raw_mode ();
       flatpak_show_cursor ();
     }
