@@ -358,15 +358,17 @@ flatpak_option_context_parse (GOptionContext     *context,
   else
     {
       if (opt_verbose > 0)
-        g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO, message_handler, NULL);
+        g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_INFO, message_handler, NULL);
       if (opt_verbose > 1)
-        g_log_set_handler (G_LOG_DOMAIN "2", G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO, message_handler, NULL);
+        g_log_set_handler (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message_handler, NULL);
 
       if (opt_ostree_verbose)
         g_log_set_handler ("OSTree", G_LOG_LEVEL_DEBUG | G_LOG_LEVEL_INFO, message_handler, NULL);
 
       if (opt_verbose > 0 || opt_ostree_verbose)
         flatpak_disable_fancy_output ();
+
+      flatpak_set_debugging (opt_verbose > 1);
     }
 
   /* sudo flatpak --user ... would operate on the root user's installation,
@@ -611,7 +613,7 @@ install_polkit_agent (void)
 
   if (bus == NULL)
     {
-      g_debug ("Unable to connect to system bus: %s", local_error->message);
+      g_info ("Unable to connect to system bus: %s", local_error->message);
       return NULL;
     }
 
@@ -619,7 +621,7 @@ install_polkit_agent (void)
   listener = flatpak_polkit_agent_text_listener_new (NULL, &local_error);
   if (listener == NULL)
     {
-      g_debug ("Failed to create polkit agent listener: %s", local_error->message);
+      g_info ("Failed to create polkit agent listener: %s", local_error->message);
     }
   else
     {
@@ -643,7 +645,7 @@ install_polkit_agent (void)
                                                            &local_error);
       if (agent == NULL)
         {
-          g_debug ("Failed to register polkit agent listener: %s", local_error->message);
+          g_info ("Failed to register polkit agent listener: %s", local_error->message);
         }
       g_object_unref (listener);
     }
@@ -679,7 +681,7 @@ flatpak_run (int      argc,
 
   if (!command->fn)
     {
-      GOptionContext *context;
+      g_autoptr(GOptionContext) context = NULL;
       g_autofree char *hint = NULL;
       g_autofree char *msg = NULL;
 
@@ -711,13 +713,13 @@ flatpak_run (int      argc,
               if (opt_version)
                 {
                   g_print ("%s\n", PACKAGE_STRING);
-                  exit (EXIT_SUCCESS);
+                  return EXIT_SUCCESS;
                 }
 
               if (opt_default_arch)
                 {
                   g_print ("%s\n", flatpak_get_arch ());
-                  exit (EXIT_SUCCESS);
+                  return EXIT_SUCCESS;
                 }
 
               if (opt_supported_arches)
@@ -726,7 +728,7 @@ flatpak_run (int      argc,
                   int i;
                   for (i = 0; arches[i] != NULL; i++)
                     g_print ("%s\n", arches[i]);
-                  exit (EXIT_SUCCESS);
+                  return EXIT_SUCCESS;
                 }
 
               if (opt_gl_drivers)
@@ -735,7 +737,7 @@ flatpak_run (int      argc,
                   int i;
                   for (i = 0; drivers[i] != NULL; i++)
                     g_print ("%s\n", drivers[i]);
-                  exit (EXIT_SUCCESS);
+                  return EXIT_SUCCESS;
                 }
 
               if (opt_list_installations)
@@ -751,7 +753,7 @@ flatpak_run (int      argc,
                           GFile *file = paths->pdata[i];
                           g_print ("%s\n", flatpak_file_get_path_cached (file));
                         }
-                      exit (EXIT_SUCCESS);
+                      return EXIT_SUCCESS;
                     }
                 }
 
@@ -777,7 +779,7 @@ flatpak_run (int      argc,
                   if (local_error != NULL)
                     {
                       g_printerr ("%s\n", local_error->message);
-                      exit (1);
+                      return 1;
                     }
 
                   for (gsize i = 0; i < system_installation_locations->len; i++)
@@ -805,7 +807,7 @@ flatpak_run (int      argc,
                   new_dirs_joined = g_strjoinv (":", (gchar **) new_dirs->pdata);
                   g_print ("XDG_DATA_DIRS=%s\n", new_dirs_joined);
 
-                  exit (EXIT_SUCCESS);
+                  return EXIT_SUCCESS;
                 }
             }
 
@@ -815,8 +817,6 @@ flatpak_run (int      argc,
             msg = g_strdup (_("No command specified"));
         }
 
-      g_option_context_free (context);
-
       g_set_error (&error, G_IO_ERROR, G_IO_ERROR_FAILED, "%s\n\n%s", msg, hint);
 
       goto out;
