@@ -15,21 +15,15 @@ for feature in $(echo $1 | sed "s/^.*@\(.*\).wrap/\1/" | tr "," "\n"); do
         deltas)
             export USE_DELTAS=yes
             ;;
+        newsummary)
+            export SUMMARY_FORMAT=new
+            ;;
+        oldsummary)
+            export SUMMARY_FORMAT=old
+            ;;
         nodeltas)
             export USE_DELTAS=no
             ;;
-        nocollections)
-            export USE_COLLECTIONS_IN_SERVER=no
-            export USE_COLLECTIONS_IN_CLIENT=no
-            ;;
-        collections)
-            export USE_COLLECTIONS_IN_SERVER=yes
-            export USE_COLLECTIONS_IN_CLIENT=yes
-            ;;
-        collections-server-only)
-            export USE_COLLECTIONS_IN_SERVER=yes
-            export USE_COLLECTIONS_IN_CLIENT=no
-            ;;
         labels)
             export USE_OCI_LABELS=yes
             ;;
